@@ -16,3 +16,7 @@
 #
 # You should have received a copy of the GNU Affero General Public License
 # along with this program. If not, see <http://www.gnu.org/licenses/>.
+
+__author__ = "OKso http://okso.me"
+__version__ = "0.2.1"
+
